@@ -71,6 +71,8 @@ as possible to Apache 2 module, reducing ifdefs in the code itself*/
 #define apr_psprintf ap_psprintf
 #define apr_uri_t uri_components
 #define apr_pool_t ap_pool
+#define apr_pool_create(a,b) *(a) = ap_make_sub_pool (b)
+#define apr_pool_destroy(a) ap_destroy_pool (a)
 #define apr_pcalloc_t ap_pcalloc_t
 #define apr_pcalloc ap_pcalloc
 
